@@ -1,39 +1,29 @@
 use crate::config::{CompressionType, ContainerType, Info};
 use crate::signature::{self, Signature};
-use anyhow::Result;
-use anyhow::{anyhow, Context};
+use anyhow::{anyhow, Context, Result};
 use clap::{value_parser, Arg, ArgAction, ArgMatches, Command};
 use ignore::WalkBuilder;
-use indicatif::MultiProgress;
-use indicatif::{ProgressBar, ProgressIterator, ProgressStyle};
+use indicatif::{MultiProgress, ProgressBar, ProgressIterator, ProgressStyle};
 use itertools::Itertools;
 use log::{debug, info, warn};
 use path_slash::PathExt;
-use relative_path::RelativePath;
-use relative_path::RelativePathBuf;
+use relative_path::{RelativePath, RelativePathBuf};
 use serde::Deserialize;
-use std::borrow::Cow;
-use std::collections::HashMap;
-use std::env::{current_dir, set_current_dir};
-use std::fmt::Display;
-use std::fs;
-use std::io::{stdin, IsTerminal, Read};
-use std::path::{Path, PathBuf};
-use std::str::FromStr;
+use std::{
+    borrow::Cow,
+    collections::HashMap,
+    env::{current_dir, set_current_dir},
+    fmt::Display,
+    fs,
+    io::{stdin, IsTerminal, Read},
+    path::{Path, PathBuf},
+    str::FromStr,
+};
 use strum::VariantNames;
 
 pub fn create_app() -> Command {
-    Command::new(env!("CARGO_PKG_NAME"))
-        .version(env!("CARGO_PKG_VERSION"))
-        .author(env!("CARGO_PKG_AUTHORS"))
-        .about(env!("CARGO_PKG_DESCRIPTION"))
-        .arg(
-            Arg::new("verbosity")
-                .short('v')
-                .long("verbose")
-                .action(ArgAction::Count)
-                .help("Sets the level of verbosity"),
-        )
+    Command::new("backup")
+        .about("Backup code and data")
         .arg(
             Arg::new("output")
                 .short('o')
@@ -49,13 +39,6 @@ pub fn create_app() -> Command {
                 .value_name("SAVE_DIR")
                 .help("Save directory in output")
         )
-        .arg(
-            Arg::new("profiles-list")
-                .short('r')
-                .long("profiles-list")
-                .action(ArgAction::SetTrue)
-                .help("List profiles")
-        )
         .arg(
             Arg::new("paths")
                 .short('p')
@@ -165,14 +148,6 @@ pub fn create_app() -> Command {
                 .help("OpenPGP secret key path")
                 .value_parser(value_parser!(PathBuf))
         )
-        .arg(
-            Arg::new("directory")
-                .short('d')
-                .long("directory")
-                .value_name("DIR")
-                .help("Current directory")
-                .value_parser(value_parser!(PathBuf))
-        )
         .arg(
             Arg::new("destination")
                 .short('n')
@@ -843,7 +818,7 @@ pub fn save(
         ));
         let save_size_progress_bar = multi_progress_bar.add(ProgressBar::new(total_size).with_style(
             ProgressStyle::with_template(
-                "{spinner} [{elapsed:6}] Current file {bytes:10}/{total_bytes:10} {wide_bar}                 Speed {bytes_per_sec}",
+                "{spinner} [{elapsed:6}] Current file {bytes:10}/{total_bytes:10} {wide_bar}                Speed {bytes_per_sec}",
             )
             .unwrap(),
         ));
@@ -878,7 +853,7 @@ pub fn save(
     // Save metadata
     if config.metadata {
         info!("Save metadata");
-        let info_yaml = serde_yaml::to_string(info)?;
+        let info_yaml = serde_yml::to_string(info)?;
         container.add_file(
             RelativePath::new("./.smc/metadata.yaml"),
             info_yaml.as_bytes(),
